@@ -1,11 +1,14 @@
 ## ------------------------------------------------------------------------
+knit_by_pkgdown <- !is.null(knitr::opts_chunk$get("fig.retina"))
 knitr::opts_chunk$set(warning = TRUE, message = TRUE, error = TRUE, echo = FALSE)
 pander::panderOptions("table.split.table", Inf)
+ggplot2::theme_set(ggplot2::theme_bw())
+
 library(codebook)
 data("bfi", package = 'codebook')
 bfi$age <- rpois(nrow(bfi), 30)
-ggplot2::theme_set(ggplot2::theme_bw())
-pander::panderOptions("table.split.table", Inf)
+library(labelled)
+var_label(bfi$age) <- "Alter"
 
 ## ----setup,eval=TRUE,echo=FALSE------------------------------------------
 if (exists("testing")) {
@@ -56,44 +59,6 @@ html_scale_name <- recursive_escape(scale_name)
 names(items) <- recursive_escape(names(items))
 scale_info <- recursive_escape(attributes(scale))
 
-## ----setup,eval=TRUE,echo=FALSE------------------------------------------
-if (!exists("indent")) {
-	indent = ''
-}
-if (exists("testing")) {
-	example("alpha", "psych")
-  x = a4
-}
-
-## ------------------------------------------------------------------------
-if (!is.null(x$total$ase)) {
-  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
-             estimate = x$total$raw_alpha, 
-             upper = x$total$raw_alpha + 1.96 * 
-  x$total$ase))
-}
-
-## ------------------------------------------------------------------------
-pander::pander(x$total)
-
-## ------------------------------------------------------------------------
-rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
-pander::pander(x$alpha.drop)
-
-## ------------------------------------------------------------------------
-rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
-pander::pander(x$item.stats)
-
-## ------------------------------------------------------------------------
-rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
-pander::pander(x$response.freq)
-
-## ----reliability, results='asis'-----------------------------------------
-for (i in seq_along(reliabilities)) {
-  rel <- reliabilities[[i]]
-  cat(knitr::knit_print(rel, indent = paste0(indent, "####")))
-}
-
 ## ----likert_setup--------------------------------------------------------
 old_height <- knitr::opts_chunk$get("fig.height")
 new_height <- length(scale_info$scale_item_names)
@@ -132,11 +97,49 @@ if (length(breaks)) {
 
 dist_plot
 
+## ----setup,eval=TRUE,echo=FALSE------------------------------------------
+if (!exists("indent")) {
+	indent = ''
+}
+if (exists("testing")) {
+	example("alpha", "psych")
+  x = a4
+}
+
+## ------------------------------------------------------------------------
+if (!is.null(x$total$ase)) {
+  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
+             estimate = x$total$raw_alpha, 
+             upper = x$total$raw_alpha + 1.96 * 
+  x$total$ase))
+}
+
+## ------------------------------------------------------------------------
+pander::pander(x$total)
+
+## ------------------------------------------------------------------------
+rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
+pander::pander(x$alpha.drop)
+
+## ------------------------------------------------------------------------
+rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
+pander::pander(x$item.stats)
+
+## ------------------------------------------------------------------------
+rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
+pander::pander(x$response.freq)
+
+## ----reliability, results='asis'-----------------------------------------
+for (i in seq_along(reliabilities)) {
+  rel <- reliabilities[[i]]
+  cat(knitr::knit_print(rel, indent = paste0(indent, "####")))
+}
+
 ## ----summary-------------------------------------------------------------
 for (i in seq_along(names(items))) {
   attributes(items[[i]]) = recursive_escape(attributes(items[[i]]))
 }
-pander::pander(codebook_table(items))
+escaped_table(codebook_table(items))
 
 ## ----setup,eval=TRUE,echo=FALSE------------------------------------------
 if (!exists("indent")) {
@@ -153,44 +156,6 @@ html_scale_name <- recursive_escape(scale_name)
 names(items) <- recursive_escape(names(items))
 scale_info <- recursive_escape(attributes(scale))
 
-## ----setup,eval=TRUE,echo=FALSE------------------------------------------
-if (!exists("indent")) {
-	indent = ''
-}
-if (exists("testing")) {
-	example("alpha", "psych")
-  x = a4
-}
-
-## ------------------------------------------------------------------------
-if (!is.null(x$total$ase)) {
-  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
-             estimate = x$total$raw_alpha, 
-             upper = x$total$raw_alpha + 1.96 * 
-  x$total$ase))
-}
-
-## ------------------------------------------------------------------------
-pander::pander(x$total)
-
-## ------------------------------------------------------------------------
-rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
-pander::pander(x$alpha.drop)
-
-## ------------------------------------------------------------------------
-rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
-pander::pander(x$item.stats)
-
-## ------------------------------------------------------------------------
-rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
-pander::pander(x$response.freq)
-
-## ----reliability, results='asis'-----------------------------------------
-for (i in seq_along(reliabilities)) {
-  rel <- reliabilities[[i]]
-  cat(knitr::knit_print(rel, indent = paste0(indent, "####")))
-}
-
 ## ----likert_setup--------------------------------------------------------
 old_height <- knitr::opts_chunk$get("fig.height")
 new_height <- length(scale_info$scale_item_names)
@@ -229,11 +194,49 @@ if (length(breaks)) {
 
 dist_plot
 
+## ----setup,eval=TRUE,echo=FALSE------------------------------------------
+if (!exists("indent")) {
+	indent = ''
+}
+if (exists("testing")) {
+	example("alpha", "psych")
+  x = a4
+}
+
+## ------------------------------------------------------------------------
+if (!is.null(x$total$ase)) {
+  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
+             estimate = x$total$raw_alpha, 
+             upper = x$total$raw_alpha + 1.96 * 
+  x$total$ase))
+}
+
+## ------------------------------------------------------------------------
+pander::pander(x$total)
+
+## ------------------------------------------------------------------------
+rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
+pander::pander(x$alpha.drop)
+
+## ------------------------------------------------------------------------
+rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
+pander::pander(x$item.stats)
+
+## ------------------------------------------------------------------------
+rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
+pander::pander(x$response.freq)
+
+## ----reliability, results='asis'-----------------------------------------
+for (i in seq_along(reliabilities)) {
+  rel <- reliabilities[[i]]
+  cat(knitr::knit_print(rel, indent = paste0(indent, "####")))
+}
+
 ## ----summary-------------------------------------------------------------
 for (i in seq_along(names(items))) {
   attributes(items[[i]]) = recursive_escape(attributes(items[[i]]))
 }
-pander::pander(codebook_table(items))
+escaped_table(codebook_table(items))
 
 ## ----setup,eval=TRUE,echo=FALSE------------------------------------------
 if (!exists("indent")) {
@@ -250,44 +253,6 @@ html_scale_name <- recursive_escape(scale_name)
 names(items) <- recursive_escape(names(items))
 scale_info <- recursive_escape(attributes(scale))
 
-## ----setup,eval=TRUE,echo=FALSE------------------------------------------
-if (!exists("indent")) {
-	indent = ''
-}
-if (exists("testing")) {
-	example("alpha", "psych")
-  x = a4
-}
-
-## ------------------------------------------------------------------------
-if (!is.null(x$total$ase)) {
-  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
-             estimate = x$total$raw_alpha, 
-             upper = x$total$raw_alpha + 1.96 * 
-  x$total$ase))
-}
-
-## ------------------------------------------------------------------------
-pander::pander(x$total)
-
-## ------------------------------------------------------------------------
-rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
-pander::pander(x$alpha.drop)
-
-## ------------------------------------------------------------------------
-rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
-pander::pander(x$item.stats)
-
-## ------------------------------------------------------------------------
-rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
-pander::pander(x$response.freq)
-
-## ----reliability, results='asis'-----------------------------------------
-for (i in seq_along(reliabilities)) {
-  rel <- reliabilities[[i]]
-  cat(knitr::knit_print(rel, indent = paste0(indent, "####")))
-}
-
 ## ----likert_setup--------------------------------------------------------
 old_height <- knitr::opts_chunk$get("fig.height")
 new_height <- length(scale_info$scale_item_names)
@@ -326,11 +291,49 @@ if (length(breaks)) {
 
 dist_plot
 
+## ----setup,eval=TRUE,echo=FALSE------------------------------------------
+if (!exists("indent")) {
+	indent = ''
+}
+if (exists("testing")) {
+	example("alpha", "psych")
+  x = a4
+}
+
+## ------------------------------------------------------------------------
+if (!is.null(x$total$ase)) {
+  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
+             estimate = x$total$raw_alpha, 
+             upper = x$total$raw_alpha + 1.96 * 
+  x$total$ase))
+}
+
+## ------------------------------------------------------------------------
+pander::pander(x$total)
+
+## ------------------------------------------------------------------------
+rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
+pander::pander(x$alpha.drop)
+
+## ------------------------------------------------------------------------
+rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
+pander::pander(x$item.stats)
+
+## ------------------------------------------------------------------------
+rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
+pander::pander(x$response.freq)
+
+## ----reliability, results='asis'-----------------------------------------
+for (i in seq_along(reliabilities)) {
+  rel <- reliabilities[[i]]
+  cat(knitr::knit_print(rel, indent = paste0(indent, "####")))
+}
+
 ## ----summary-------------------------------------------------------------
 for (i in seq_along(names(items))) {
   attributes(items[[i]]) = recursive_escape(attributes(items[[i]]))
 }
-pander::pander(codebook_table(items))
+escaped_table(codebook_table(items))
 
 ## ----setup,eval=TRUE,echo=FALSE------------------------------------------
 if (!exists("indent")) {
@@ -347,44 +350,6 @@ html_scale_name <- recursive_escape(scale_name)
 names(items) <- recursive_escape(names(items))
 scale_info <- recursive_escape(attributes(scale))
 
-## ----setup,eval=TRUE,echo=FALSE------------------------------------------
-if (!exists("indent")) {
-	indent = ''
-}
-if (exists("testing")) {
-	example("alpha", "psych")
-  x = a4
-}
-
-## ------------------------------------------------------------------------
-if (!is.null(x$total$ase)) {
-  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
-             estimate = x$total$raw_alpha, 
-             upper = x$total$raw_alpha + 1.96 * 
-  x$total$ase))
-}
-
-## ------------------------------------------------------------------------
-pander::pander(x$total)
-
-## ------------------------------------------------------------------------
-rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
-pander::pander(x$alpha.drop)
-
-## ------------------------------------------------------------------------
-rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
-pander::pander(x$item.stats)
-
-## ------------------------------------------------------------------------
-rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
-pander::pander(x$response.freq)
-
-## ----reliability, results='asis'-----------------------------------------
-for (i in seq_along(reliabilities)) {
-  rel <- reliabilities[[i]]
-  cat(knitr::knit_print(rel, indent = paste0(indent, "####")))
-}
-
 ## ----likert_setup--------------------------------------------------------
 old_height <- knitr::opts_chunk$get("fig.height")
 new_height <- length(scale_info$scale_item_names)
@@ -423,11 +388,49 @@ if (length(breaks)) {
 
 dist_plot
 
+## ----setup,eval=TRUE,echo=FALSE------------------------------------------
+if (!exists("indent")) {
+	indent = ''
+}
+if (exists("testing")) {
+	example("alpha", "psych")
+  x = a4
+}
+
+## ------------------------------------------------------------------------
+if (!is.null(x$total$ase)) {
+  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
+             estimate = x$total$raw_alpha, 
+             upper = x$total$raw_alpha + 1.96 * 
+  x$total$ase))
+}
+
+## ------------------------------------------------------------------------
+pander::pander(x$total)
+
+## ------------------------------------------------------------------------
+rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
+pander::pander(x$alpha.drop)
+
+## ------------------------------------------------------------------------
+rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
+pander::pander(x$item.stats)
+
+## ------------------------------------------------------------------------
+rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
+pander::pander(x$response.freq)
+
+## ----reliability, results='asis'-----------------------------------------
+for (i in seq_along(reliabilities)) {
+  rel <- reliabilities[[i]]
+  cat(knitr::knit_print(rel, indent = paste0(indent, "####")))
+}
+
 ## ----summary-------------------------------------------------------------
 for (i in seq_along(names(items))) {
   attributes(items[[i]]) = recursive_escape(attributes(items[[i]]))
 }
-pander::pander(codebook_table(items))
+escaped_table(codebook_table(items))
 
 ## ----setup,eval=TRUE,echo=FALSE------------------------------------------
 if (!exists("indent")) {
@@ -444,44 +447,6 @@ html_scale_name <- recursive_escape(scale_name)
 names(items) <- recursive_escape(names(items))
 scale_info <- recursive_escape(attributes(scale))
 
-## ----setup,eval=TRUE,echo=FALSE------------------------------------------
-if (!exists("indent")) {
-	indent = ''
-}
-if (exists("testing")) {
-	example("alpha", "psych")
-  x = a4
-}
-
-## ------------------------------------------------------------------------
-if (!is.null(x$total$ase)) {
-  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
-             estimate = x$total$raw_alpha, 
-             upper = x$total$raw_alpha + 1.96 * 
-  x$total$ase))
-}
-
-## ------------------------------------------------------------------------
-pander::pander(x$total)
-
-## ------------------------------------------------------------------------
-rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
-pander::pander(x$alpha.drop)
-
-## ------------------------------------------------------------------------
-rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
-pander::pander(x$item.stats)
-
-## ------------------------------------------------------------------------
-rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
-pander::pander(x$response.freq)
-
-## ----reliability, results='asis'-----------------------------------------
-for (i in seq_along(reliabilities)) {
-  rel <- reliabilities[[i]]
-  cat(knitr::knit_print(rel, indent = paste0(indent, "####")))
-}
-
 ## ----likert_setup--------------------------------------------------------
 old_height <- knitr::opts_chunk$get("fig.height")
 new_height <- length(scale_info$scale_item_names)
@@ -520,11 +485,49 @@ if (length(breaks)) {
 
 dist_plot
 
+## ----setup,eval=TRUE,echo=FALSE------------------------------------------
+if (!exists("indent")) {
+	indent = ''
+}
+if (exists("testing")) {
+	example("alpha", "psych")
+  x = a4
+}
+
+## ------------------------------------------------------------------------
+if (!is.null(x$total$ase)) {
+  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
+             estimate = x$total$raw_alpha, 
+             upper = x$total$raw_alpha + 1.96 * 
+  x$total$ase))
+}
+
+## ------------------------------------------------------------------------
+pander::pander(x$total)
+
+## ------------------------------------------------------------------------
+rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
+pander::pander(x$alpha.drop)
+
+## ------------------------------------------------------------------------
+rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
+pander::pander(x$item.stats)
+
+## ------------------------------------------------------------------------
+rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
+pander::pander(x$response.freq)
+
+## ----reliability, results='asis'-----------------------------------------
+for (i in seq_along(reliabilities)) {
+  rel <- reliabilities[[i]]
+  cat(knitr::knit_print(rel, indent = paste0(indent, "####")))
+}
+
 ## ----summary-------------------------------------------------------------
 for (i in seq_along(names(items))) {
   attributes(items[[i]]) = recursive_escape(attributes(items[[i]]))
 }
-pander::pander(codebook_table(items))
+escaped_table(codebook_table(items))
 
 ## ----setup,eval=TRUE,echo=FALSE------------------------------------------
 if (!exists("indent")) {
@@ -545,7 +548,7 @@ choices <- item_attributes$labels
 
 ## ----setup_missings------------------------------------------------------
 show_missings <- FALSE
-if (haven::is.labelled(item)) {
+if (has_label(item)) {
   missings <- item[is.na(haven::zap_missing(item))]
   attributes(missings) <- attributes(item)
   if (!is.null(attributes(item)$labels)) {
@@ -610,9 +613,9 @@ knitr::opts_chunk$set(fig.height = old_height)
 
 ## ----summary-------------------------------------------------------------
 attributes(item) <- item_attributes
-df = data.frame(item)
+df = data.frame(item, stringsAsFactors = FALSE)
 names(df) = html_item_name
-knitr::kable(codebook_table(df), escape = TRUE)
+escaped_table(codebook_table(df))
 
 ## ----missings------------------------------------------------------------
 if (show_missings) {
@@ -661,24 +664,6 @@ if (length(md_pattern)) {
   pander::pander(md_pattern)
 }
 
-## ----setup,eval=TRUE,echo=FALSE------------------------------------------
-if (!exists("indent")) {
-	indent <- '#' # ugly hack
-}
-if (exists("testing")) {
-	results <- data.frame()
-	metadata_table = data.frame()
-}
-
-## ----items, message=TRUE-------------------------------------------------
-export_table(metadata_table)
-
-## ----setup,eval=TRUE,echo=FALSE------------------------------------------
-if (exists("testing")) {
-	indent = '#' # ugly hack so _regression_summary can be "spun" (variables included via `r ` have to be available)
-	results = data.frame()
-}
-
 ## ----setup,eval=TRUE,echo=FALSE------------------------------------------
 if (!exists("indent")) {
 	indent <- '#' # ugly hack
@@ -708,5 +693,10 @@ items
 jsonld
 
 ## ----cb------------------------------------------------------------------
-codebook(bfi)
+codebook(bfi, metadata_table = knit_by_pkgdown, metadata_json = knit_by_pkgdown)
+
+## ------------------------------------------------------------------------
+if (!knit_by_pkgdown) {
+  codebook:::escaped_table(codebook_table(bfi))
+}
 
